==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>ビットマップとしてエクスポート</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>ビットマップファイルの生成中にエラー &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>ビットマップファイルはエクスポートされました &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>ビットマップエクスポート</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>図面単位あたりのピクセル数:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>余白:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>ピクセル</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>白</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>黒</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;m ビットマップエクスポート...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+119"/>
        <source>Files</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>ビットマップとしてエクスポート</translation>
    </message>
    <message>
        <location line="-51"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>ビットマップファイルの生成中にエラー &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>ビットマップファイルはエクスポートされました &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>ビットマップエクスポート</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>図面単位あたりのピクセル数:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Export bounding box of selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Transparent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+23"/>
        <source>Color</source>
        <translation>色</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Monochrome</source>
        <translation>モノクロ</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Grayscale</source>
        <translation>グレースケール</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Anti-aliasing</source>
        <translation>アンチエイリアス</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use anti-aliasing</source>
        <translation>アンチエイリアスを使用</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Margin</source>
        <translation>余白</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin:</source>
        <translation>余白:</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>px</source>
        <translation>ピクセル</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add extra margin to compensate for line weight</source>
        <translation>線分太さと相殺するために余分な余白を追加</translation>
    </message>
    <message>
        <location line="-170"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>白</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>黒</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;m ビットマップエクスポート...</translation>
    </message>
</context>
<context>
    <name>BitmapExportWorker</name>
    <message>
        <location filename="../BitmapExportWorker.js" line="+106"/>
        <source>Invalid image size (width x height must be less than %1)</source>
        <translation> 無効な画像サイズ(幅x高さは%1よりも小さく)</translation>
    </message>
</context>
</TS>
